from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DialogFilterChatlist(BaseModel):
    """
    types.DialogFilterChatlist
    ID: 0x9fe28ea4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DialogFilterChatlist', 'DialogFilterChatlist'] = pydantic.Field(
        'types.DialogFilterChatlist',
        alias='_'
    )

    id: int
    title: str
    pinned_peers: list["base.InputPeer"]
    include_peers: list["base.InputPeer"]
    has_my_invites: typing.Optional[bool] = None
    emoticon: typing.Optional[str] = None
    color: typing.Optional[int] = None



from .get_users import GetUsers
from .get_full_user import GetFullUser
from .set_secure_value_errors import SetSecureValueErrors
from .get_is_premium_required_to_contact import GetIsPremiumRequiredToContact



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ConnectedBot(BaseModel):
    """
    types.ConnectedBot
    ID: 0xbd068601
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ConnectedBot', 'ConnectedBot'] = pydantic.Field(
        'types.ConnectedBot',
        alias='_'
    )

    bot_id: int
    recipients: "base.BusinessBotRecipients"
    can_reply: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputSecureFileUploaded(BaseModel):
    """
    types.InputSecureFileUploaded
    ID: 0x3334b0f0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputSecureFileUploaded', 'InputSecureFileUploaded'] = pydantic.Field(
        'types.InputSecureFileUploaded',
        alias='_'
    )

    id: int
    parts: int
    md5_checksum: str
    file_hash: Bytes
    secret: Bytes



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# NotificationSound - Layer 181
NotificationSound = typing.Annotated[
    typing.Union[
        typing.Annotated[types.NotificationSoundDefault, pydantic.Tag('NotificationSoundDefault')],
        typing.Annotated[types.NotificationSoundLocal, pydantic.Tag('NotificationSoundLocal')],
        typing.Annotated[types.NotificationSoundNone, pydantic.Tag('NotificationSoundNone')],
        typing.Annotated[types.NotificationSoundRingtone, pydantic.Tag('NotificationSoundRingtone')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotApp - Layer 181
BotApp = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BotApp, pydantic.Tag('BotApp')],
        typing.Annotated[types.BotAppNotModified, pydantic.Tag('BotAppNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetDifference(BaseModel):
    """
    functions.updates.GetDifference
    ID: 0x19c2f763
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.updates.GetDifference', 'GetDifference'] = pydantic.Field(
        'functions.updates.GetDifference',
        alias='_'
    )

    pts: int
    date: Datetime
    qts: int
    pts_limit: typing.Optional[int] = None
    pts_total_limit: typing.Optional[int] = None
    qts_limit: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageReplyHeader(BaseModel):
    """
    types.MessageReplyHeader
    ID: 0xafbc09db
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageReplyHeader', 'MessageReplyHeader'] = pydantic.Field(
        'types.MessageReplyHeader',
        alias='_'
    )

    reply_to_scheduled: typing.Optional[bool] = None
    forum_topic: typing.Optional[bool] = None
    quote: typing.Optional[bool] = None
    reply_to_msg_id: typing.Optional[int] = None
    reply_to_peer_id: typing.Optional["base.Peer"] = None
    reply_from: typing.Optional["base.MessageFwdHeader"] = None
    reply_media: typing.Optional["base.MessageMedia"] = None
    reply_to_top_id: typing.Optional[int] = None
    quote_text: typing.Optional[str] = None
    quote_entities: typing.Optional[list["base.MessageEntity"]] = None
    quote_offset: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneConnectionWebrtc(BaseModel):
    """
    types.PhoneConnectionWebrtc
    ID: 0x635fe375
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneConnectionWebrtc', 'PhoneConnectionWebrtc'] = pydantic.Field(
        'types.PhoneConnectionWebrtc',
        alias='_'
    )

    id: int
    ip: str
    ipv6: str
    port: int
    username: str
    password: str
    turn: typing.Optional[bool] = None
    stun: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.EmojiStatuses - Layer 181
EmojiStatuses = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.EmojiStatuses, pydantic.Tag('account.EmojiStatuses')],
        typing.Annotated[types.account.EmojiStatusesNotModified, pydantic.Tag('account.EmojiStatusesNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetStickerSetThumb(BaseModel):
    """
    functions.stickers.SetStickerSetThumb
    ID: 0xa76a5392
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stickers.SetStickerSetThumb', 'SetStickerSetThumb'] = pydantic.Field(
        'functions.stickers.SetStickerSetThumb',
        alias='_'
    )

    stickerset: "base.InputStickerSet"
    thumb: typing.Optional["base.InputDocument"] = None
    thumb_document_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PromoData(BaseModel):
    """
    types.help.PromoData
    ID: 0x8c39793f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.PromoData', 'PromoData'] = pydantic.Field(
        'types.help.PromoData',
        alias='_'
    )

    expires: Datetime
    peer: "base.Peer"
    chats: list["base.Chat"]
    users: list["base.User"]
    proxy: typing.Optional[bool] = None
    psa_type: typing.Optional[str] = None
    psa_message: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StickerKeyword(BaseModel):
    """
    types.StickerKeyword
    ID: 0xfcfeb29c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StickerKeyword', 'StickerKeyword'] = pydantic.Field(
        'types.StickerKeyword',
        alias='_'
    )

    document_id: int
    keyword: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ToggleGroupCallSettings(BaseModel):
    """
    functions.phone.ToggleGroupCallSettings
    ID: 0x74bbb43d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.ToggleGroupCallSettings', 'ToggleGroupCallSettings'] = pydantic.Field(
        'functions.phone.ToggleGroupCallSettings',
        alias='_'
    )

    call: "base.InputGroupCall"
    reset_invite_hash: typing.Optional[bool] = None
    join_muted: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputWallPaper - Layer 181
InputWallPaper = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputWallPaper, pydantic.Tag('InputWallPaper')],
        typing.Annotated[types.InputWallPaperNoFile, pydantic.Tag('InputWallPaperNoFile')],
        typing.Annotated[types.InputWallPaperSlug, pydantic.Tag('InputWallPaperSlug')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptEncryption(BaseModel):
    """
    functions.messages.AcceptEncryption
    ID: 0x3dbc0415
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.AcceptEncryption', 'AcceptEncryption'] = pydantic.Field(
        'functions.messages.AcceptEncryption',
        alias='_'
    )

    peer: "base.InputEncryptedChat"
    g_b: Bytes
    key_fingerprint: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RegisterDevice(BaseModel):
    """
    functions.account.RegisterDevice
    ID: 0xec86017a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.RegisterDevice', 'RegisterDevice'] = pydantic.Field(
        'functions.account.RegisterDevice',
        alias='_'
    )

    token_type: int
    token: str
    app_sandbox: bool
    secret: Bytes
    other_uids: list[int]
    no_muted: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AuthorizationForm(BaseModel):
    """
    types.account.AuthorizationForm
    ID: 0xad2e1cd8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.AuthorizationForm', 'AuthorizationForm'] = pydantic.Field(
        'types.account.AuthorizationForm',
        alias='_'
    )

    required_types: list["base.SecureRequiredType"]
    values: list["base.SecureValue"]
    errors: list["base.SecureValueError"]
    users: list["base.User"]
    privacy_policy_url: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# stats.PublicForwards - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
PublicForwards = typing.Union[
    typing.Annotated[types.stats.PublicForwards, pydantic.Tag('stats.PublicForwards')]
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StatsGraph - Layer 181
StatsGraph = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StatsGraph, pydantic.Tag('StatsGraph')],
        typing.Annotated[types.StatsGraphAsync, pydantic.Tag('StatsGraphAsync')],
        typing.Annotated[types.StatsGraphError, pydantic.Tag('StatsGraphError')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhoneCall - Layer 181
PhoneCall = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PhoneCall, pydantic.Tag('PhoneCall')],
        typing.Annotated[types.PhoneCallAccepted, pydantic.Tag('PhoneCallAccepted')],
        typing.Annotated[types.PhoneCallDiscarded, pydantic.Tag('PhoneCallDiscarded')],
        typing.Annotated[types.PhoneCallEmpty, pydantic.Tag('PhoneCallEmpty')],
        typing.Annotated[types.PhoneCallRequested, pydantic.Tag('PhoneCallRequested')],
        typing.Annotated[types.PhoneCallWaiting, pydantic.Tag('PhoneCallWaiting')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CreateForumTopic(BaseModel):
    """
    functions.channels.CreateForumTopic
    ID: 0xf40c0224
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.CreateForumTopic', 'CreateForumTopic'] = pydantic.Field(
        'functions.channels.CreateForumTopic',
        alias='_'
    )

    channel: "base.InputChannel"
    title: str
    random_id: int
    icon_color: typing.Optional[int] = None
    icon_emoji_id: typing.Optional[int] = None
    send_as: typing.Optional["base.InputPeer"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputReplyTo - Layer 181
InputReplyTo = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputReplyToMessage, pydantic.Tag('InputReplyToMessage')],
        typing.Annotated[types.InputReplyToStory, pydantic.Tag('InputReplyToStory')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WallPaper - Layer 181
WallPaper = typing.Annotated[
    typing.Union[
        typing.Annotated[types.WallPaper, pydantic.Tag('WallPaper')],
        typing.Annotated[types.WallPaperNoFile, pydantic.Tag('WallPaperNoFile')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputPaymentCredentialsApplePay(BaseModel):
    """
    types.InputPaymentCredentialsApplePay
    ID: 0xaa1c39f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputPaymentCredentialsApplePay', 'InputPaymentCredentialsApplePay'] = pydantic.Field(
        'types.InputPaymentCredentialsApplePay',
        alias='_'
    )

    payment_data: "base.DataJSON"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SignIn(BaseModel):
    """
    functions.auth.SignIn
    ID: 0x8d52a951
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.SignIn', 'SignIn'] = pydantic.Field(
        'functions.auth.SignIn',
        alias='_'
    )

    phone_number: str
    phone_code_hash: str
    phone_code: typing.Optional[str] = None
    email_verification: typing.Optional["base.EmailVerification"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotEditBusinessMessage(BaseModel):
    """
    types.UpdateBotEditBusinessMessage
    ID: 0x7df587c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotEditBusinessMessage', 'UpdateBotEditBusinessMessage'] = pydantic.Field(
        'types.UpdateBotEditBusinessMessage',
        alias='_'
    )

    connection_id: str
    message: "base.Message"
    qts: int
    reply_to_message: typing.Optional["base.Message"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AutoDownloadSettings(BaseModel):
    """
    types.AutoDownloadSettings
    ID: 0xbaa57628
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AutoDownloadSettings', 'AutoDownloadSettings'] = pydantic.Field(
        'types.AutoDownloadSettings',
        alias='_'
    )

    photo_size_max: int
    video_size_max: int
    file_size_max: int
    video_upload_maxbitrate: int
    small_queue_active_operations_max: int
    large_queue_active_operations_max: int
    disabled: typing.Optional[bool] = None
    video_preload_large: typing.Optional[bool] = None
    audio_preload_next: typing.Optional[bool] = None
    phonecalls_less_data: typing.Optional[bool] = None
    stories_preload: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageRange(BaseModel):
    """
    types.MessageRange
    ID: 0xae30253
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageRange', 'MessageRange'] = pydantic.Field(
        'types.MessageRange',
        alias='_'
    )

    min_id: int
    max_id: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StickerSetFullCovered(BaseModel):
    """
    types.StickerSetFullCovered
    ID: 0x40d13c0e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StickerSetFullCovered', 'StickerSetFullCovered'] = pydantic.Field(
        'types.StickerSetFullCovered',
        alias='_'
    )

    set: "base.StickerSet"
    packs: list["base.StickerPack"]
    keywords: list["base.StickerKeyword"]
    documents: list["base.Document"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBlocked(BaseModel):
    """
    functions.contacts.SetBlocked
    ID: 0x94c65c76
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.SetBlocked', 'SetBlocked'] = pydantic.Field(
        'functions.contacts.SetBlocked',
        alias='_'
    )

    id: list["base.InputPeer"]
    limit: int
    my_stories_from: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetStoryStats(BaseModel):
    """
    functions.stats.GetStoryStats
    ID: 0x374fef40
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stats.GetStoryStats', 'GetStoryStats'] = pydantic.Field(
        'functions.stats.GetStoryStats',
        alias='_'
    )

    peer: "base.InputPeer"
    id: int
    dark: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotInfo(BaseModel):
    """
    types.bots.BotInfo
    ID: 0xe8a775b0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.bots.BotInfo', 'BotInfo'] = pydantic.Field(
        'types.bots.BotInfo',
        alias='_'
    )

    name: str
    about: str
    description: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditUserInfo(BaseModel):
    """
    functions.help.EditUserInfo
    ID: 0x66b91b70
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.help.EditUserInfo', 'EditUserInfo'] = pydantic.Field(
        'functions.help.EditUserInfo',
        alias='_'
    )

    user_id: "base.InputUser"
    message: str
    entities: list["base.MessageEntity"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputTheme - Layer 181
InputTheme = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputTheme, pydantic.Tag('InputTheme')],
        typing.Annotated[types.InputThemeSlug, pydantic.Tag('InputThemeSlug')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AppUpdate(BaseModel):
    """
    types.help.AppUpdate
    ID: 0xccbbce30
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.AppUpdate', 'AppUpdate'] = pydantic.Field(
        'types.help.AppUpdate',
        alias='_'
    )

    id: int
    version: str
    text: str
    entities: list["base.MessageEntity"]
    can_not_skip: typing.Optional[bool] = None
    document: typing.Optional["base.Document"] = None
    url: typing.Optional[str] = None
    sticker: typing.Optional["base.Document"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Update - Layer 181
Update = typing.Annotated[
    typing.Union[
        typing.Annotated[types.UpdateAttachMenuBots, pydantic.Tag('UpdateAttachMenuBots')],
        typing.Annotated[types.UpdateAutoSaveSettings, pydantic.Tag('UpdateAutoSaveSettings')],
        typing.Annotated[types.UpdateBotBusinessConnect, pydantic.Tag('UpdateBotBusinessConnect')],
        typing.Annotated[types.UpdateBotCallbackQuery, pydantic.Tag('UpdateBotCallbackQuery')],
        typing.Annotated[types.UpdateBotChatBoost, pydantic.Tag('UpdateBotChatBoost')],
        typing.Annotated[types.UpdateBotChatInviteRequester, pydantic.Tag('UpdateBotChatInviteRequester')],
        typing.Annotated[types.UpdateBotCommands, pydantic.Tag('UpdateBotCommands')],
        typing.Annotated[types.UpdateBotDeleteBusinessMessage, pydantic.Tag('UpdateBotDeleteBusinessMessage')],
        typing.Annotated[types.UpdateBotEditBusinessMessage, pydantic.Tag('UpdateBotEditBusinessMessage')],
        typing.Annotated[types.UpdateBotInlineQuery, pydantic.Tag('UpdateBotInlineQuery')],
        typing.Annotated[types.UpdateBotInlineSend, pydantic.Tag('UpdateBotInlineSend')],
        typing.Annotated[types.UpdateBotMenuButton, pydantic.Tag('UpdateBotMenuButton')],
        typing.Annotated[types.UpdateBotMessageReaction, pydantic.Tag('UpdateBotMessageReaction')],
        typing.Annotated[types.UpdateBotMessageReactions, pydantic.Tag('UpdateBotMessageReactions')],
        typing.Annotated[types.UpdateBotNewBusinessMessage, pydantic.Tag('UpdateBotNewBusinessMessage')],
        typing.Annotated[types.UpdateBotPrecheckoutQuery, pydantic.Tag('UpdateBotPrecheckoutQuery')],
        typing.Annotated[types.UpdateBotShippingQuery, pydantic.Tag('UpdateBotShippingQuery')],
        typing.Annotated[types.UpdateBotStopped, pydantic.Tag('UpdateBotStopped')],
        typing.Annotated[types.UpdateBotWebhookJSON, pydantic.Tag('UpdateBotWebhookJSON')],
        typing.Annotated[types.UpdateBotWebhookJSONQuery, pydantic.Tag('UpdateBotWebhookJSONQuery')],
        typing.Annotated[types.UpdateBroadcastRevenueTransactions, pydantic.Tag('UpdateBroadcastRevenueTransactions')],
        typing.Annotated[types.UpdateChannel, pydantic.Tag('UpdateChannel')],
        typing.Annotated[types.UpdateChannelAvailableMessages, pydantic.Tag('UpdateChannelAvailableMessages')],
        typing.Annotated[types.UpdateChannelMessageForwards, pydantic.Tag('UpdateChannelMessageForwards')],
        typing.Annotated[types.UpdateChannelMessageViews, pydantic.Tag('UpdateChannelMessageViews')],
        typing.Annotated[types.UpdateChannelParticipant, pydantic.Tag('UpdateChannelParticipant')],
        typing.Annotated[types.UpdateChannelPinnedTopic, pydantic.Tag('UpdateChannelPinnedTopic')],
        typing.Annotated[types.UpdateChannelPinnedTopics, pydantic.Tag('UpdateChannelPinnedTopics')],
        typing.Annotated[types.UpdateChannelReadMessagesContents, pydantic.Tag('UpdateChannelReadMessagesContents')],
        typing.Annotated[types.UpdateChannelTooLong, pydantic.Tag('UpdateChannelTooLong')],
        typing.Annotated[types.UpdateChannelUserTyping, pydantic.Tag('UpdateChannelUserTyping')],
        typing.Annotated[types.UpdateChannelViewForumAsMessages, pydantic.Tag('UpdateChannelViewForumAsMessages')],
        typing.Annotated[types.UpdateChannelWebPage, pydantic.Tag('UpdateChannelWebPage')],
        typing.Annotated[types.UpdateChat, pydantic.Tag('UpdateChat')],
        typing.Annotated[types.UpdateChatDefaultBannedRights, pydantic.Tag('UpdateChatDefaultBannedRights')],
        typing.Annotated[types.UpdateChatParticipant, pydantic.Tag('UpdateChatParticipant')],
        typing.Annotated[types.UpdateChatParticipantAdd, pydantic.Tag('UpdateChatParticipantAdd')],
        typing.Annotated[types.UpdateChatParticipantAdmin, pydantic.Tag('UpdateChatParticipantAdmin')],
        typing.Annotated[types.UpdateChatParticipantDelete, pydantic.Tag('UpdateChatParticipantDelete')],
        typing.Annotated[types.UpdateChatParticipants, pydantic.Tag('UpdateChatParticipants')],
        typing.Annotated[types.UpdateChatUserTyping, pydantic.Tag('UpdateChatUserTyping')],
        typing.Annotated[types.UpdateConfig, pydantic.Tag('UpdateConfig')],
        typing.Annotated[types.UpdateContactsReset, pydantic.Tag('UpdateContactsReset')],
        typing.Annotated[types.UpdateDcOptions, pydantic.Tag('UpdateDcOptions')],
        typing.Annotated[types.UpdateDeleteChannelMessages, pydantic.Tag('UpdateDeleteChannelMessages')],
        typing.Annotated[types.UpdateDeleteMessages, pydantic.Tag('UpdateDeleteMessages')],
        typing.Annotated[types.UpdateDeleteQuickReply, pydantic.Tag('UpdateDeleteQuickReply')],
        typing.Annotated[types.UpdateDeleteQuickReplyMessages, pydantic.Tag('UpdateDeleteQuickReplyMessages')],
        typing.Annotated[types.UpdateDeleteScheduledMessages, pydantic.Tag('UpdateDeleteScheduledMessages')],
        typing.Annotated[types.UpdateDialogFilter, pydantic.Tag('UpdateDialogFilter')],
        typing.Annotated[types.UpdateDialogFilterOrder, pydantic.Tag('UpdateDialogFilterOrder')],
        typing.Annotated[types.UpdateDialogFilters, pydantic.Tag('UpdateDialogFilters')],
        typing.Annotated[types.UpdateDialogPinned, pydantic.Tag('UpdateDialogPinned')],
        typing.Annotated[types.UpdateDialogUnreadMark, pydantic.Tag('UpdateDialogUnreadMark')],
        typing.Annotated[types.UpdateDraftMessage, pydantic.Tag('UpdateDraftMessage')],
        typing.Annotated[types.UpdateEditChannelMessage, pydantic.Tag('UpdateEditChannelMessage')],
        typing.Annotated[types.UpdateEditMessage, pydantic.Tag('UpdateEditMessage')],
        typing.Annotated[types.UpdateEncryptedChatTyping, pydantic.Tag('UpdateEncryptedChatTyping')],
        typing.Annotated[types.UpdateEncryptedMessagesRead, pydantic.Tag('UpdateEncryptedMessagesRead')],
        typing.Annotated[types.UpdateEncryption, pydantic.Tag('UpdateEncryption')],
        typing.Annotated[types.UpdateFavedStickers, pydantic.Tag('UpdateFavedStickers')],
        typing.Annotated[types.UpdateFolderPeers, pydantic.Tag('UpdateFolderPeers')],
        typing.Annotated[types.UpdateGeoLiveViewed, pydantic.Tag('UpdateGeoLiveViewed')],
        typing.Annotated[types.UpdateGroupCall, pydantic.Tag('UpdateGroupCall')],
        typing.Annotated[types.UpdateGroupCallConnection, pydantic.Tag('UpdateGroupCallConnection')],
        typing.Annotated[types.UpdateGroupCallParticipants, pydantic.Tag('UpdateGroupCallParticipants')],
        typing.Annotated[types.UpdateInlineBotCallbackQuery, pydantic.Tag('UpdateInlineBotCallbackQuery')],
        typing.Annotated[types.UpdateLangPack, pydantic.Tag('UpdateLangPack')],
        typing.Annotated[types.UpdateLangPackTooLong, pydantic.Tag('UpdateLangPackTooLong')],
        typing.Annotated[types.UpdateLoginToken, pydantic.Tag('UpdateLoginToken')],
        typing.Annotated[types.UpdateMessageExtendedMedia, pydantic.Tag('UpdateMessageExtendedMedia')],
        typing.Annotated[types.UpdateMessageID, pydantic.Tag('UpdateMessageID')],
        typing.Annotated[types.UpdateMessagePoll, pydantic.Tag('UpdateMessagePoll')],
        typing.Annotated[types.UpdateMessagePollVote, pydantic.Tag('UpdateMessagePollVote')],
        typing.Annotated[types.UpdateMessageReactions, pydantic.Tag('UpdateMessageReactions')],
        typing.Annotated[types.UpdateMoveStickerSetToTop, pydantic.Tag('UpdateMoveStickerSetToTop')],
        typing.Annotated[types.UpdateNewAuthorization, pydantic.Tag('UpdateNewAuthorization')],
        typing.Annotated[types.UpdateNewChannelMessage, pydantic.Tag('UpdateNewChannelMessage')],
        typing.Annotated[types.UpdateNewEncryptedMessage, pydantic.Tag('UpdateNewEncryptedMessage')],
        typing.Annotated[types.UpdateNewMessage, pydantic.Tag('UpdateNewMessage')],
        typing.Annotated[types.UpdateNewQuickReply, pydantic.Tag('UpdateNewQuickReply')],
        typing.Annotated[types.UpdateNewScheduledMessage, pydantic.Tag('UpdateNewScheduledMessage')],
        typing.Annotated[types.UpdateNewStickerSet, pydantic.Tag('UpdateNewStickerSet')],
        typing.Annotated[types.UpdateNewStoryReaction, pydantic.Tag('UpdateNewStoryReaction')],
        typing.Annotated[types.UpdateNotifySettings, pydantic.Tag('UpdateNotifySettings')],
        typing.Annotated[types.UpdatePeerBlocked, pydantic.Tag('UpdatePeerBlocked')],
        typing.Annotated[types.UpdatePeerHistoryTTL, pydantic.Tag('UpdatePeerHistoryTTL')],
        typing.Annotated[types.UpdatePeerLocated, pydantic.Tag('UpdatePeerLocated')],
        typing.Annotated[types.UpdatePeerSettings, pydantic.Tag('UpdatePeerSettings')],
        typing.Annotated[types.UpdatePeerWallpaper, pydantic.Tag('UpdatePeerWallpaper')],
        typing.Annotated[types.UpdatePendingJoinRequests, pydantic.Tag('UpdatePendingJoinRequests')],
        typing.Annotated[types.UpdatePhoneCall, pydantic.Tag('UpdatePhoneCall')],
        typing.Annotated[types.UpdatePhoneCallSignalingData, pydantic.Tag('UpdatePhoneCallSignalingData')],
        typing.Annotated[types.UpdatePinnedChannelMessages, pydantic.Tag('UpdatePinnedChannelMessages')],
        typing.Annotated[types.UpdatePinnedDialogs, pydantic.Tag('UpdatePinnedDialogs')],
        typing.Annotated[types.UpdatePinnedMessages, pydantic.Tag('UpdatePinnedMessages')],
        typing.Annotated[types.UpdatePinnedSavedDialogs, pydantic.Tag('UpdatePinnedSavedDialogs')],
        typing.Annotated[types.UpdatePrivacy, pydantic.Tag('UpdatePrivacy')],
        typing.Annotated[types.UpdatePtsChanged, pydantic.Tag('UpdatePtsChanged')],
        typing.Annotated[types.UpdateQuickReplies, pydantic.Tag('UpdateQuickReplies')],
        typing.Annotated[types.UpdateQuickReplyMessage, pydantic.Tag('UpdateQuickReplyMessage')],
        typing.Annotated[types.UpdateReadChannelDiscussionInbox, pydantic.Tag('UpdateReadChannelDiscussionInbox')],
        typing.Annotated[types.UpdateReadChannelDiscussionOutbox, pydantic.Tag('UpdateReadChannelDiscussionOutbox')],
        typing.Annotated[types.UpdateReadChannelInbox, pydantic.Tag('UpdateReadChannelInbox')],
        typing.Annotated[types.UpdateReadChannelOutbox, pydantic.Tag('UpdateReadChannelOutbox')],
        typing.Annotated[types.UpdateReadFeaturedEmojiStickers, pydantic.Tag('UpdateReadFeaturedEmojiStickers')],
        typing.Annotated[types.UpdateReadFeaturedStickers, pydantic.Tag('UpdateReadFeaturedStickers')],
        typing.Annotated[types.UpdateReadHistoryInbox, pydantic.Tag('UpdateReadHistoryInbox')],
        typing.Annotated[types.UpdateReadHistoryOutbox, pydantic.Tag('UpdateReadHistoryOutbox')],
        typing.Annotated[types.UpdateReadMessagesContents, pydantic.Tag('UpdateReadMessagesContents')],
        typing.Annotated[types.UpdateReadStories, pydantic.Tag('UpdateReadStories')],
        typing.Annotated[types.UpdateRecentEmojiStatuses, pydantic.Tag('UpdateRecentEmojiStatuses')],
        typing.Annotated[types.UpdateRecentReactions, pydantic.Tag('UpdateRecentReactions')],
        typing.Annotated[types.UpdateRecentStickers, pydantic.Tag('UpdateRecentStickers')],
        typing.Annotated[types.UpdateSavedDialogPinned, pydantic.Tag('UpdateSavedDialogPinned')],
        typing.Annotated[types.UpdateSavedGifs, pydantic.Tag('UpdateSavedGifs')],
        typing.Annotated[types.UpdateSavedReactionTags, pydantic.Tag('UpdateSavedReactionTags')],
        typing.Annotated[types.UpdateSavedRingtones, pydantic.Tag('UpdateSavedRingtones')],
        typing.Annotated[types.UpdateSentStoryReaction, pydantic.Tag('UpdateSentStoryReaction')],
        typing.Annotated[types.UpdateServiceNotification, pydantic.Tag('UpdateServiceNotification')],
        typing.Annotated[types.UpdateSmsJob, pydantic.Tag('UpdateSmsJob')],
        typing.Annotated[types.UpdateStarsBalance, pydantic.Tag('UpdateStarsBalance')],
        typing.Annotated[types.UpdateStickerSets, pydantic.Tag('UpdateStickerSets')],
        typing.Annotated[types.UpdateStickerSetsOrder, pydantic.Tag('UpdateStickerSetsOrder')],
        typing.Annotated[types.UpdateStoriesStealthMode, pydantic.Tag('UpdateStoriesStealthMode')],
        typing.Annotated[types.UpdateStory, pydantic.Tag('UpdateStory')],
        typing.Annotated[types.UpdateStoryID, pydantic.Tag('UpdateStoryID')],
        typing.Annotated[types.UpdateTheme, pydantic.Tag('UpdateTheme')],
        typing.Annotated[types.UpdateTranscribedAudio, pydantic.Tag('UpdateTranscribedAudio')],
        typing.Annotated[types.UpdateUser, pydantic.Tag('UpdateUser')],
        typing.Annotated[types.UpdateUserEmojiStatus, pydantic.Tag('UpdateUserEmojiStatus')],
        typing.Annotated[types.UpdateUserName, pydantic.Tag('UpdateUserName')],
        typing.Annotated[types.UpdateUserPhone, pydantic.Tag('UpdateUserPhone')],
        typing.Annotated[types.UpdateUserStatus, pydantic.Tag('UpdateUserStatus')],
        typing.Annotated[types.UpdateUserTyping, pydantic.Tag('UpdateUserTyping')],
        typing.Annotated[types.UpdateWebPage, pydantic.Tag('UpdateWebPage')],
        typing.Annotated[types.UpdateWebViewResultSent, pydantic.Tag('UpdateWebViewResultSent')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBotUpdatesStatus(BaseModel):
    """
    functions.help.SetBotUpdatesStatus
    ID: 0xec22cfcd
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.help.SetBotUpdatesStatus', 'SetBotUpdatesStatus'] = pydantic.Field(
        'functions.help.SetBotUpdatesStatus',
        alias='_'
    )

    pending_updates_count: int
    message: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentCodeTypeFirebaseSms(BaseModel):
    """
    types.auth.SentCodeTypeFirebaseSms
    ID: 0x13c90f17
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.SentCodeTypeFirebaseSms', 'SentCodeTypeFirebaseSms'] = pydantic.Field(
        'types.auth.SentCodeTypeFirebaseSms',
        alias='_'
    )

    length: int
    nonce: typing.Optional[Bytes] = None
    play_integrity_nonce: typing.Optional[Bytes] = None
    receipt: typing.Optional[str] = None
    push_timeout: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelParticipantSelf(BaseModel):
    """
    types.ChannelParticipantSelf
    ID: 0x35a8bfa7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelParticipantSelf', 'ChannelParticipantSelf'] = pydantic.Field(
        'types.ChannelParticipantSelf',
        alias='_'
    )

    user_id: int
    inviter_id: int
    date: Datetime
    via_request: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.TimezonesList - Layer 181
TimezonesList = typing.Annotated[
    typing.Union[
        typing.Annotated[types.help.TimezonesList, pydantic.Tag('help.TimezonesList')],
        typing.Annotated[types.help.TimezonesListNotModified, pydantic.Tag('help.TimezonesListNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReplyKeyboardForceReply(BaseModel):
    """
    types.ReplyKeyboardForceReply
    ID: 0x86b40b08
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ReplyKeyboardForceReply', 'ReplyKeyboardForceReply'] = pydantic.Field(
        'types.ReplyKeyboardForceReply',
        alias='_'
    )

    single_use: typing.Optional[bool] = None
    selective: typing.Optional[bool] = None
    placeholder: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# KeyboardButton - Layer 181
KeyboardButton = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputKeyboardButtonRequestPeer, pydantic.Tag('InputKeyboardButtonRequestPeer')],
        typing.Annotated[types.InputKeyboardButtonUrlAuth, pydantic.Tag('InputKeyboardButtonUrlAuth')],
        typing.Annotated[types.InputKeyboardButtonUserProfile, pydantic.Tag('InputKeyboardButtonUserProfile')],
        typing.Annotated[types.KeyboardButton, pydantic.Tag('KeyboardButton')],
        typing.Annotated[types.KeyboardButtonBuy, pydantic.Tag('KeyboardButtonBuy')],
        typing.Annotated[types.KeyboardButtonCallback, pydantic.Tag('KeyboardButtonCallback')],
        typing.Annotated[types.KeyboardButtonGame, pydantic.Tag('KeyboardButtonGame')],
        typing.Annotated[types.KeyboardButtonRequestGeoLocation, pydantic.Tag('KeyboardButtonRequestGeoLocation')],
        typing.Annotated[types.KeyboardButtonRequestPeer, pydantic.Tag('KeyboardButtonRequestPeer')],
        typing.Annotated[types.KeyboardButtonRequestPhone, pydantic.Tag('KeyboardButtonRequestPhone')],
        typing.Annotated[types.KeyboardButtonRequestPoll, pydantic.Tag('KeyboardButtonRequestPoll')],
        typing.Annotated[types.KeyboardButtonSimpleWebView, pydantic.Tag('KeyboardButtonSimpleWebView')],
        typing.Annotated[types.KeyboardButtonSwitchInline, pydantic.Tag('KeyboardButtonSwitchInline')],
        typing.Annotated[types.KeyboardButtonUrl, pydantic.Tag('KeyboardButtonUrl')],
        typing.Annotated[types.KeyboardButtonUrlAuth, pydantic.Tag('KeyboardButtonUrlAuth')],
        typing.Annotated[types.KeyboardButtonUserProfile, pydantic.Tag('KeyboardButtonUserProfile')],
        typing.Annotated[types.KeyboardButtonWebView, pydantic.Tag('KeyboardButtonWebView')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputWebDocument(BaseModel):
    """
    types.InputWebDocument
    ID: 0x9bed434d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputWebDocument', 'InputWebDocument'] = pydantic.Field(
        'types.InputWebDocument',
        alias='_'
    )

    url: str
    size: int
    mime_type: str
    attributes: list["base.DocumentAttribute"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EncryptedFile(BaseModel):
    """
    types.EncryptedFile
    ID: 0xa8008cd8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EncryptedFile', 'EncryptedFile'] = pydantic.Field(
        'types.EncryptedFile',
        alias='_'
    )

    id: int
    access_hash: int
    size: int
    dc_id: int
    key_fingerprint: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PeerStories(BaseModel):
    """
    types.PeerStories
    ID: 0x9a35e999
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PeerStories', 'PeerStories'] = pydantic.Field(
        'types.PeerStories',
        alias='_'
    )

    peer: "base.Peer"
    stories: list["base.StoryItem"]
    max_read_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputUser - Layer 181
InputUser = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputUser, pydantic.Tag('InputUser')],
        typing.Annotated[types.InputUserEmpty, pydantic.Tag('InputUserEmpty')],
        typing.Annotated[types.InputUserFromMessage, pydantic.Tag('InputUserFromMessage')],
        typing.Annotated[types.InputUserSelf, pydantic.Tag('InputUserSelf')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# storage.FileType - Layer 181
FileType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.storage.FileGif, pydantic.Tag('storage.FileGif')],
        typing.Annotated[types.storage.FileJpeg, pydantic.Tag('storage.FileJpeg')],
        typing.Annotated[types.storage.FileMov, pydantic.Tag('storage.FileMov')],
        typing.Annotated[types.storage.FileMp3, pydantic.Tag('storage.FileMp3')],
        typing.Annotated[types.storage.FileMp4, pydantic.Tag('storage.FileMp4')],
        typing.Annotated[types.storage.FilePartial, pydantic.Tag('storage.FilePartial')],
        typing.Annotated[types.storage.FilePdf, pydantic.Tag('storage.FilePdf')],
        typing.Annotated[types.storage.FilePng, pydantic.Tag('storage.FilePng')],
        typing.Annotated[types.storage.FileUnknown, pydantic.Tag('storage.FileUnknown')],
        typing.Annotated[types.storage.FileWebp, pydantic.Tag('storage.FileWebp')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StickerSetCovered - Layer 181
StickerSetCovered = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StickerSetCovered, pydantic.Tag('StickerSetCovered')],
        typing.Annotated[types.StickerSetFullCovered, pydantic.Tag('StickerSetFullCovered')],
        typing.Annotated[types.StickerSetMultiCovered, pydantic.Tag('StickerSetMultiCovered')],
        typing.Annotated[types.StickerSetNoCovered, pydantic.Tag('StickerSetNoCovered')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MaskCoords(BaseModel):
    """
    types.MaskCoords
    ID: 0xaed6dbb2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MaskCoords', 'MaskCoords'] = pydantic.Field(
        'types.MaskCoords',
        alias='_'
    )

    n: int
    x: float
    y: float
    zoom: float



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionWebViewDataSentMe(BaseModel):
    """
    types.MessageActionWebViewDataSentMe
    ID: 0x47dd8079
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionWebViewDataSentMe', 'MessageActionWebViewDataSentMe'] = pydantic.Field(
        'types.MessageActionWebViewDataSentMe',
        alias='_'
    )

    text: str
    data: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendPaymentForm(BaseModel):
    """
    functions.payments.SendPaymentForm
    ID: 0x2d03522f
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.payments.SendPaymentForm', 'SendPaymentForm'] = pydantic.Field(
        'functions.payments.SendPaymentForm',
        alias='_'
    )

    form_id: int
    invoice: "base.InputInvoice"
    credentials: "base.InputPaymentCredentials"
    requested_info_id: typing.Optional[str] = None
    shipping_option_id: typing.Optional[str] = None
    tip_amount: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InvokeAfterMsgs(BaseModel):
    """
    functions.InvokeAfterMsgs
    ID: 0x3dc4b4f0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.InvokeAfterMsgs', 'InvokeAfterMsgs'] = pydantic.Field(
        'functions.InvokeAfterMsgs',
        alias='_'
    )

    msg_ids: list[int]
    query: BaseModel



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageMedia - Layer 181
MessageMedia = typing.Annotated[
    typing.Union[
        typing.Annotated[types.MessageMediaContact, pydantic.Tag('MessageMediaContact')],
        typing.Annotated[types.MessageMediaDice, pydantic.Tag('MessageMediaDice')],
        typing.Annotated[types.MessageMediaDocument, pydantic.Tag('MessageMediaDocument')],
        typing.Annotated[types.MessageMediaEmpty, pydantic.Tag('MessageMediaEmpty')],
        typing.Annotated[types.MessageMediaGame, pydantic.Tag('MessageMediaGame')],
        typing.Annotated[types.MessageMediaGeo, pydantic.Tag('MessageMediaGeo')],
        typing.Annotated[types.MessageMediaGeoLive, pydantic.Tag('MessageMediaGeoLive')],
        typing.Annotated[types.MessageMediaGiveaway, pydantic.Tag('MessageMediaGiveaway')],
        typing.Annotated[types.MessageMediaGiveawayResults, pydantic.Tag('MessageMediaGiveawayResults')],
        typing.Annotated[types.MessageMediaInvoice, pydantic.Tag('MessageMediaInvoice')],
        typing.Annotated[types.MessageMediaPhoto, pydantic.Tag('MessageMediaPhoto')],
        typing.Annotated[types.MessageMediaPoll, pydantic.Tag('MessageMediaPoll')],
        typing.Annotated[types.MessageMediaStory, pydantic.Tag('MessageMediaStory')],
        typing.Annotated[types.MessageMediaUnsupported, pydantic.Tag('MessageMediaUnsupported')],
        typing.Annotated[types.MessageMediaVenue, pydantic.Tag('MessageMediaVenue')],
        typing.Annotated[types.MessageMediaWebPage, pydantic.Tag('MessageMediaWebPage')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetGameScore(BaseModel):
    """
    functions.messages.SetGameScore
    ID: 0x8ef8ecc0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetGameScore', 'SetGameScore'] = pydantic.Field(
        'functions.messages.SetGameScore',
        alias='_'
    )

    peer: "base.InputPeer"
    id: int
    user_id: "base.InputUser"
    score: int
    edit_message: typing.Optional[bool] = None
    force: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaVenue(BaseModel):
    """
    types.InputMediaVenue
    ID: 0xc13d1c11
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaVenue', 'InputMediaVenue'] = pydantic.Field(
        'types.InputMediaVenue',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"
    title: str
    address: str
    provider: str
    venue_id: str
    venue_type: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UploadContactProfilePhoto(BaseModel):
    """
    functions.photos.UploadContactProfilePhoto
    ID: 0xe14c4a71
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.photos.UploadContactProfilePhoto', 'UploadContactProfilePhoto'] = pydantic.Field(
        'functions.photos.UploadContactProfilePhoto',
        alias='_'
    )

    user_id: "base.InputUser"
    suggest: typing.Optional[bool] = None
    save: typing.Optional[bool] = None
    file: typing.Optional["base.InputFile"] = None
    video: typing.Optional["base.InputFile"] = None
    video_start_ts: typing.Optional[float] = None
    video_emoji_markup: typing.Optional["base.VideoSize"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AttachMenuBotIcon(BaseModel):
    """
    types.AttachMenuBotIcon
    ID: 0xb2a7386b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AttachMenuBotIcon', 'AttachMenuBotIcon'] = pydantic.Field(
        'types.AttachMenuBotIcon',
        alias='_'
    )

    name: str
    icon: "base.Document"
    colors: typing.Optional[list["base.AttachMenuBotIconColor"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# VideoSize - Layer 181
VideoSize = typing.Annotated[
    typing.Union[
        typing.Annotated[types.VideoSize, pydantic.Tag('VideoSize')],
        typing.Annotated[types.VideoSizeEmojiMarkup, pydantic.Tag('VideoSizeEmojiMarkup')],
        typing.Annotated[types.VideoSizeStickerMarkup, pydantic.Tag('VideoSizeStickerMarkup')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaGeoLive(BaseModel):
    """
    types.InputMediaGeoLive
    ID: 0x971fa843
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaGeoLive', 'InputMediaGeoLive'] = pydantic.Field(
        'types.InputMediaGeoLive',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"
    stopped: typing.Optional[bool] = None
    heading: typing.Optional[int] = None
    period: typing.Optional[int] = None
    proximity_notification_radius: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBotInfo(BaseModel):
    """
    functions.bots.SetBotInfo
    ID: 0x10cf3123
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.bots.SetBotInfo', 'SetBotInfo'] = pydantic.Field(
        'functions.bots.SetBotInfo',
        alias='_'
    )

    lang_code: str
    bot: typing.Optional["base.InputUser"] = None
    name: typing.Optional[str] = None
    about: typing.Optional[str] = None
    description: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MissingInvitee(BaseModel):
    """
    types.MissingInvitee
    ID: 0x628c9224
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MissingInvitee', 'MissingInvitee'] = pydantic.Field(
        'types.MissingInvitee',
        alias='_'
    )

    user_id: int
    premium_would_allow_invite: typing.Optional[bool] = None
    premium_required_for_pm: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.ResetPasswordResult - Layer 181
ResetPasswordResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.ResetPasswordFailedWait, pydantic.Tag('account.ResetPasswordFailedWait')],
        typing.Annotated[types.account.ResetPasswordOk, pydantic.Tag('account.ResetPasswordOk')],
        typing.Annotated[types.account.ResetPasswordRequestedWait, pydantic.Tag('account.ResetPasswordRequestedWait')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetLanguage(BaseModel):
    """
    functions.langpack.GetLanguage
    ID: 0x6a596502
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.langpack.GetLanguage', 'GetLanguage'] = pydantic.Field(
        'functions.langpack.GetLanguage',
        alias='_'
    )

    lang_pack: str
    lang_code: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotInlineMediaResult(BaseModel):
    """
    types.BotInlineMediaResult
    ID: 0x17db940b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BotInlineMediaResult', 'BotInlineMediaResult'] = pydantic.Field(
        'types.BotInlineMediaResult',
        alias='_'
    )

    id: str
    type: str
    send_message: "base.BotInlineMessage"
    photo: typing.Optional["base.Photo"] = None
    document: typing.Optional["base.Document"] = None
    title: typing.Optional[str] = None
    description: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SavedInfo(BaseModel):
    """
    types.payments.SavedInfo
    ID: 0xfb8fe43c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.SavedInfo', 'SavedInfo'] = pydantic.Field(
        'types.payments.SavedInfo',
        alias='_'
    )

    has_saved_credentials: typing.Optional[bool] = None
    saved_info: typing.Optional["base.PaymentRequestedInfo"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Invoice(BaseModel):
    """
    types.Invoice
    ID: 0x5db95a15
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Invoice', 'Invoice'] = pydantic.Field(
        'types.Invoice',
        alias='_'
    )

    currency: str
    prices: list["base.LabeledPrice"]
    test: typing.Optional[bool] = None
    name_requested: typing.Optional[bool] = None
    phone_requested: typing.Optional[bool] = None
    email_requested: typing.Optional[bool] = None
    shipping_address_requested: typing.Optional[bool] = None
    flexible: typing.Optional[bool] = None
    phone_to_provider: typing.Optional[bool] = None
    email_to_provider: typing.Optional[bool] = None
    recurring: typing.Optional[bool] = None
    max_tip_amount: typing.Optional[int] = None
    suggested_tip_amounts: typing.Optional[list[int]] = None
    terms_url: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputGame - Layer 181
InputGame = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputGameID, pydantic.Tag('InputGameID')],
        typing.Annotated[types.InputGameShortName, pydantic.Tag('InputGameShortName')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmojiStatus - Layer 181
EmojiStatus = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EmojiStatus, pydantic.Tag('EmojiStatus')],
        typing.Annotated[types.EmojiStatusEmpty, pydantic.Tag('EmojiStatusEmpty')],
        typing.Annotated[types.EmojiStatusUntil, pydantic.Tag('EmojiStatusUntil')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateChatParticipantAdd(BaseModel):
    """
    types.UpdateChatParticipantAdd
    ID: 0x3dda5451
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateChatParticipantAdd', 'UpdateChatParticipantAdd'] = pydantic.Field(
        'types.UpdateChatParticipantAdd',
        alias='_'
    )

    chat_id: int
    user_id: int
    inviter_id: int
    date: Datetime
    version: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPrivacyRule - Layer 181
InputPrivacyRule = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputPrivacyValueAllowAll, pydantic.Tag('InputPrivacyValueAllowAll')],
        typing.Annotated[types.InputPrivacyValueAllowChatParticipants, pydantic.Tag('InputPrivacyValueAllowChatParticipants')],
        typing.Annotated[types.InputPrivacyValueAllowCloseFriends, pydantic.Tag('InputPrivacyValueAllowCloseFriends')],
        typing.Annotated[types.InputPrivacyValueAllowContacts, pydantic.Tag('InputPrivacyValueAllowContacts')],
        typing.Annotated[types.InputPrivacyValueAllowPremium, pydantic.Tag('InputPrivacyValueAllowPremium')],
        typing.Annotated[types.InputPrivacyValueAllowUsers, pydantic.Tag('InputPrivacyValueAllowUsers')],
        typing.Annotated[types.InputPrivacyValueDisallowAll, pydantic.Tag('InputPrivacyValueDisallowAll')],
        typing.Annotated[types.InputPrivacyValueDisallowChatParticipants, pydantic.Tag('InputPrivacyValueDisallowChatParticipants')],
        typing.Annotated[types.InputPrivacyValueDisallowContacts, pydantic.Tag('InputPrivacyValueDisallowContacts')],
        typing.Annotated[types.InputPrivacyValueDisallowUsers, pydantic.Tag('InputPrivacyValueDisallowUsers')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.SentCode - Layer 181
SentCode = typing.Annotated[
    typing.Union[
        typing.Annotated[types.auth.SentCode, pydantic.Tag('auth.SentCode')],
        typing.Annotated[types.auth.SentCodeSuccess, pydantic.Tag('auth.SentCodeSuccess')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# GeoPoint - Layer 181
GeoPoint = typing.Annotated[
    typing.Union[
        typing.Annotated[types.GeoPoint, pydantic.Tag('GeoPoint')],
        typing.Annotated[types.GeoPointEmpty, pydantic.Tag('GeoPointEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MediaArea - Layer 181
MediaArea = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputMediaAreaChannelPost, pydantic.Tag('InputMediaAreaChannelPost')],
        typing.Annotated[types.InputMediaAreaVenue, pydantic.Tag('InputMediaAreaVenue')],
        typing.Annotated[types.MediaAreaChannelPost, pydantic.Tag('MediaAreaChannelPost')],
        typing.Annotated[types.MediaAreaGeoPoint, pydantic.Tag('MediaAreaGeoPoint')],
        typing.Annotated[types.MediaAreaSuggestedReaction, pydantic.Tag('MediaAreaSuggestedReaction')],
        typing.Annotated[types.MediaAreaVenue, pydantic.Tag('MediaAreaVenue')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmailVerifyPurpose - Layer 181
EmailVerifyPurpose = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EmailVerifyPurposeLoginChange, pydantic.Tag('EmailVerifyPurposeLoginChange')],
        typing.Annotated[types.EmailVerifyPurposeLoginSetup, pydantic.Tag('EmailVerifyPurposeLoginSetup')],
        typing.Annotated[types.EmailVerifyPurposePassport, pydantic.Tag('EmailVerifyPurposePassport')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotChatInviteRequester(BaseModel):
    """
    types.UpdateBotChatInviteRequester
    ID: 0x11dfa986
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotChatInviteRequester', 'UpdateBotChatInviteRequester'] = pydantic.Field(
        'types.UpdateBotChatInviteRequester',
        alias='_'
    )

    peer: "base.Peer"
    date: Datetime
    user_id: int
    about: str
    invite: "base.ExportedChatInvite"
    qts: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# LangPackString - Layer 181
LangPackString = typing.Annotated[
    typing.Union[
        typing.Annotated[types.LangPackString, pydantic.Tag('LangPackString')],
        typing.Annotated[types.LangPackStringDeleted, pydantic.Tag('LangPackStringDeleted')],
        typing.Annotated[types.LangPackStringPluralized, pydantic.Tag('LangPackStringPluralized')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateMessageExtendedMedia(BaseModel):
    """
    types.UpdateMessageExtendedMedia
    ID: 0x5a73a98c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateMessageExtendedMedia', 'UpdateMessageExtendedMedia'] = pydantic.Field(
        'types.UpdateMessageExtendedMedia',
        alias='_'
    )

    peer: "base.Peer"
    msg_id: int
    extended_media: "base.MessageExtendedMedia"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReorderStickerSets(BaseModel):
    """
    functions.messages.ReorderStickerSets
    ID: 0x78337739
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ReorderStickerSets', 'ReorderStickerSets'] = pydantic.Field(
        'functions.messages.ReorderStickerSets',
        alias='_'
    )

    order: list[int]
    masks: typing.Optional[bool] = None
    emojis: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SuggestedShortName(BaseModel):
    """
    types.stickers.SuggestedShortName
    ID: 0x85fea03f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stickers.SuggestedShortName', 'SuggestedShortName'] = pydantic.Field(
        'types.stickers.SuggestedShortName',
        alias='_'
    )

    short_name: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.CodeType - Layer 181
CodeType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.auth.CodeTypeCall, pydantic.Tag('auth.CodeTypeCall')],
        typing.Annotated[types.auth.CodeTypeFlashCall, pydantic.Tag('auth.CodeTypeFlashCall')],
        typing.Annotated[types.auth.CodeTypeFragmentSms, pydantic.Tag('auth.CodeTypeFragmentSms')],
        typing.Annotated[types.auth.CodeTypeMissedCall, pydantic.Tag('auth.CodeTypeMissedCall')],
        typing.Annotated[types.auth.CodeTypeSms, pydantic.Tag('auth.CodeTypeSms')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelFull(BaseModel):
    """
    types.ChannelFull
    ID: 0xbbab348d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelFull', 'ChannelFull'] = pydantic.Field(
        'types.ChannelFull',
        alias='_'
    )

    id: int
    about: str
    read_inbox_max_id: int
    read_outbox_max_id: int
    unread_count: int
    chat_photo: "base.Photo"
    notify_settings: "base.PeerNotifySettings"
    bot_info: list["base.BotInfo"]
    pts: int
    can_view_participants: typing.Optional[bool] = None
    can_set_username: typing.Optional[bool] = None
    can_set_stickers: typing.Optional[bool] = None
    hidden_prehistory: typing.Optional[bool] = None
    can_set_location: typing.Optional[bool] = None
    has_scheduled: typing.Optional[bool] = None
    can_view_stats: typing.Optional[bool] = None
    blocked: typing.Optional[bool] = None
    can_delete_channel: typing.Optional[bool] = None
    antispam: typing.Optional[bool] = None
    participants_hidden: typing.Optional[bool] = None
    translations_disabled: typing.Optional[bool] = None
    stories_pinned_available: typing.Optional[bool] = None
    view_forum_as_messages: typing.Optional[bool] = None
    restricted_sponsored: typing.Optional[bool] = None
    can_view_revenue: typing.Optional[bool] = None
    participants_count: typing.Optional[int] = None
    admins_count: typing.Optional[int] = None
    kicked_count: typing.Optional[int] = None
    banned_count: typing.Optional[int] = None
    online_count: typing.Optional[int] = None
    exported_invite: typing.Optional["base.ExportedChatInvite"] = None
    migrated_from_chat_id: typing.Optional[int] = None
    migrated_from_max_id: typing.Optional[int] = None
    pinned_msg_id: typing.Optional[int] = None
    stickerset: typing.Optional["base.StickerSet"] = None
    available_min_id: typing.Optional[int] = None
    folder_id: typing.Optional[int] = None
    linked_chat_id: typing.Optional[int] = None
    location: typing.Optional["base.ChannelLocation"] = None
    slowmode_seconds: typing.Optional[int] = None
    slowmode_next_send_date: typing.Optional[Datetime] = None
    stats_dc: typing.Optional[int] = None
    call: typing.Optional["base.InputGroupCall"] = None
    ttl_period: typing.Optional[int] = None
    pending_suggestions: typing.Optional[list[str]] = None
    groupcall_default_join_as: typing.Optional["base.Peer"] = None
    theme_emoticon: typing.Optional[str] = None
    requests_pending: typing.Optional[int] = None
    recent_requesters: typing.Optional[list[int]] = None
    default_send_as: typing.Optional["base.Peer"] = None
    available_reactions: typing.Optional["base.ChatReactions"] = None
    reactions_limit: typing.Optional[int] = None
    stories: typing.Optional["base.PeerStories"] = None
    wallpaper: typing.Optional["base.WallPaper"] = None
    boosts_applied: typing.Optional[int] = None
    boosts_unrestrict: typing.Optional[int] = None
    emojiset: typing.Optional["base.StickerSet"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WallPaperNoFile(BaseModel):
    """
    types.WallPaperNoFile
    ID: 0xe0804116
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WallPaperNoFile', 'WallPaperNoFile'] = pydantic.Field(
        'types.WallPaperNoFile',
        alias='_'
    )

    id: int
    default: typing.Optional[bool] = None
    dark: typing.Optional[bool] = None
    settings: typing.Optional["base.WallPaperSettings"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportGroupCallInvite(BaseModel):
    """
    functions.phone.ExportGroupCallInvite
    ID: 0xe6aa647f
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.ExportGroupCallInvite', 'ExportGroupCallInvite'] = pydantic.Field(
        'functions.phone.ExportGroupCallInvite',
        alias='_'
    )

    call: "base.InputGroupCall"
    can_self_unmute: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RequestPeerType - Layer 181
RequestPeerType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.RequestPeerTypeBroadcast, pydantic.Tag('RequestPeerTypeBroadcast')],
        typing.Annotated[types.RequestPeerTypeChat, pydantic.Tag('RequestPeerTypeChat')],
        typing.Annotated[types.RequestPeerTypeUser, pydantic.Tag('RequestPeerTypeUser')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BusinessLocation(BaseModel):
    """
    types.BusinessLocation
    ID: 0xac5c1af7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BusinessLocation', 'BusinessLocation'] = pydantic.Field(
        'types.BusinessLocation',
        alias='_'
    )

    address: str
    geo_point: typing.Optional["base.GeoPoint"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmojiStatuses(BaseModel):
    """
    types.account.EmojiStatuses
    ID: 0x90c467d1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.EmojiStatuses', 'EmojiStatuses'] = pydantic.Field(
        'types.account.EmojiStatuses',
        alias='_'
    )

    hash: int
    statuses: list["base.EmojiStatus"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Stories(BaseModel):
    """
    types.stories.Stories
    ID: 0x63c3dd0a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stories.Stories', 'Stories'] = pydantic.Field(
        'types.stories.Stories',
        alias='_'
    )

    count: int
    stories: list["base.StoryItem"]
    chats: list["base.Chat"]
    users: list["base.User"]
    pinned_to_top: typing.Optional[list[int]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReorderPinnedSavedDialogs(BaseModel):
    """
    functions.messages.ReorderPinnedSavedDialogs
    ID: 0x8b716587
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ReorderPinnedSavedDialogs', 'ReorderPinnedSavedDialogs'] = pydantic.Field(
        'functions.messages.ReorderPinnedSavedDialogs',
        alias='_'
    )

    order: list["base.InputDialogPeer"]
    force: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReplyKeyboardHide(BaseModel):
    """
    types.ReplyKeyboardHide
    ID: 0xa03e5b85
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ReplyKeyboardHide', 'ReplyKeyboardHide'] = pydantic.Field(
        'types.ReplyKeyboardHide',
        alias='_'
    )

    selective: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryItem(BaseModel):
    """
    types.StoryItem
    ID: 0x79b26a24
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryItem', 'StoryItem'] = pydantic.Field(
        'types.StoryItem',
        alias='_'
    )

    id: int
    date: Datetime
    expire_date: Datetime
    media: "base.MessageMedia"
    pinned: typing.Optional[bool] = None
    public: typing.Optional[bool] = None
    close_friends: typing.Optional[bool] = None
    min: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    edited: typing.Optional[bool] = None
    contacts: typing.Optional[bool] = None
    selected_contacts: typing.Optional[bool] = None
    out: typing.Optional[bool] = None
    from_id: typing.Optional["base.Peer"] = None
    fwd_from: typing.Optional["base.StoryFwdHeader"] = None
    caption: typing.Optional[str] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    media_areas: typing.Optional[list["base.MediaArea"]] = None
    privacy: typing.Optional[list["base.PrivacyRule"]] = None
    views: typing.Optional["base.StoryViews"] = None
    sent_reaction: typing.Optional["base.Reaction"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# UserProfilePhoto - Layer 181
UserProfilePhoto = typing.Annotated[
    typing.Union[
        typing.Annotated[types.UserProfilePhoto, pydantic.Tag('UserProfilePhoto')],
        typing.Annotated[types.UserProfilePhotoEmpty, pydantic.Tag('UserProfilePhotoEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AttachMenuBotsBot(BaseModel):
    """
    types.AttachMenuBotsBot
    ID: 0x93bf667f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AttachMenuBotsBot', 'AttachMenuBotsBot'] = pydantic.Field(
        'types.AttachMenuBotsBot',
        alias='_'
    )

    bot: "base.AttachMenuBot"
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CheckRecoveryPassword(BaseModel):
    """
    functions.auth.CheckRecoveryPassword
    ID: 0xd36bf79
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.CheckRecoveryPassword', 'CheckRecoveryPassword'] = pydantic.Field(
        'functions.auth.CheckRecoveryPassword',
        alias='_'
    )

    code: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateProfilePhoto(BaseModel):
    """
    functions.photos.UpdateProfilePhoto
    ID: 0x9e82039
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.photos.UpdateProfilePhoto', 'UpdateProfilePhoto'] = pydantic.Field(
        'functions.photos.UpdateProfilePhoto',
        alias='_'
    )

    id: "base.InputPhoto"
    fallback: typing.Optional[bool] = None
    bot: typing.Optional["base.InputUser"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BusinessWorkHours(BaseModel):
    """
    types.BusinessWorkHours
    ID: 0x8c92b098
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BusinessWorkHours', 'BusinessWorkHours'] = pydantic.Field(
        'types.BusinessWorkHours',
        alias='_'
    )

    timezone_id: str
    weekly_open: list["base.BusinessWeeklyOpen"]
    open_now: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputSecureFile - Layer 181
InputSecureFile = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputSecureFile, pydantic.Tag('InputSecureFile')],
        typing.Annotated[types.InputSecureFileUploaded, pydantic.Tag('InputSecureFileUploaded')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetChatInviteImporters(BaseModel):
    """
    functions.messages.GetChatInviteImporters
    ID: 0xdf04dd4e
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetChatInviteImporters', 'GetChatInviteImporters'] = pydantic.Field(
        'functions.messages.GetChatInviteImporters',
        alias='_'
    )

    peer: "base.InputPeer"
    offset_date: Datetime
    offset_user: "base.InputUser"
    limit: int
    requested: typing.Optional[bool] = None
    link: typing.Optional[str] = None
    q: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmailVerifiedLogin(BaseModel):
    """
    types.account.EmailVerifiedLogin
    ID: 0xe1bb0d61
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.EmailVerifiedLogin', 'EmailVerifiedLogin'] = pydantic.Field(
        'types.account.EmailVerifiedLogin',
        alias='_'
    )

    email: str
    sent_code: "base.auth.SentCode"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaInvoice(BaseModel):
    """
    types.InputMediaInvoice
    ID: 0x405fef0d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaInvoice', 'InputMediaInvoice'] = pydantic.Field(
        'types.InputMediaInvoice',
        alias='_'
    )

    title: str
    description: str
    invoice: "base.Invoice"
    payload: Bytes
    provider_data: "base.DataJSON"
    photo: typing.Optional["base.InputWebDocument"] = None
    provider: typing.Optional[str] = None
    start_param: typing.Optional[str] = None
    extended_media: typing.Optional["base.InputMedia"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatReactions - Layer 181
ChatReactions = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChatReactionsAll, pydantic.Tag('ChatReactionsAll')],
        typing.Annotated[types.ChatReactionsNone, pydantic.Tag('ChatReactionsNone')],
        typing.Annotated[types.ChatReactionsSome, pydantic.Tag('ChatReactionsSome')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ToggleBotInAttachMenu(BaseModel):
    """
    functions.messages.ToggleBotInAttachMenu
    ID: 0x69f59d69
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ToggleBotInAttachMenu', 'ToggleBotInAttachMenu'] = pydantic.Field(
        'functions.messages.ToggleBotInAttachMenu',
        alias='_'
    )

    bot: "base.InputUser"
    enabled: bool
    write_allowed: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryViews(BaseModel):
    """
    types.stories.StoryViews
    ID: 0xde9eed1d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stories.StoryViews', 'StoryViews'] = pydantic.Field(
        'types.stories.StoryViews',
        alias='_'
    )

    views: list["base.StoryViews"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputBotInlineMessage - Layer 181
InputBotInlineMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputBotInlineMessageGame, pydantic.Tag('InputBotInlineMessageGame')],
        typing.Annotated[types.InputBotInlineMessageMediaAuto, pydantic.Tag('InputBotInlineMessageMediaAuto')],
        typing.Annotated[types.InputBotInlineMessageMediaContact, pydantic.Tag('InputBotInlineMessageMediaContact')],
        typing.Annotated[types.InputBotInlineMessageMediaGeo, pydantic.Tag('InputBotInlineMessageMediaGeo')],
        typing.Annotated[types.InputBotInlineMessageMediaInvoice, pydantic.Tag('InputBotInlineMessageMediaInvoice')],
        typing.Annotated[types.InputBotInlineMessageMediaVenue, pydantic.Tag('InputBotInlineMessageMediaVenue')],
        typing.Annotated[types.InputBotInlineMessageMediaWebPage, pydantic.Tag('InputBotInlineMessageMediaWebPage')],
        typing.Annotated[types.InputBotInlineMessageText, pydantic.Tag('InputBotInlineMessageText')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InitHistoryImport(BaseModel):
    """
    functions.messages.InitHistoryImport
    ID: 0x34090c3b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.InitHistoryImport', 'InitHistoryImport'] = pydantic.Field(
        'functions.messages.InitHistoryImport',
        alias='_'
    )

    peer: "base.InputPeer"
    file: "base.InputFile"
    media_count: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# DraftMessage - Layer 181
DraftMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.DraftMessage, pydantic.Tag('DraftMessage')],
        typing.Annotated[types.DraftMessageEmpty, pydantic.Tag('DraftMessageEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.SavedRingtone - Layer 181
SavedRingtone = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.SavedRingtone, pydantic.Tag('account.SavedRingtone')],
        typing.Annotated[types.account.SavedRingtoneConverted, pydantic.Tag('account.SavedRingtoneConverted')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DeletePhotos(BaseModel):
    """
    functions.photos.DeletePhotos
    ID: 0x87cf7f2f
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.photos.DeletePhotos', 'DeletePhotos'] = pydantic.Field(
        'functions.photos.DeletePhotos',
        alias='_'
    )

    id: list["base.InputPhoto"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PasswordKdfAlgo - Layer 181
PasswordKdfAlgo = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow, pydantic.Tag('PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow')],
        typing.Annotated[types.PasswordKdfAlgoUnknown, pydantic.Tag('PasswordKdfAlgoUnknown')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ValidatedRequestedInfo(BaseModel):
    """
    types.payments.ValidatedRequestedInfo
    ID: 0xd1451883
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.ValidatedRequestedInfo', 'ValidatedRequestedInfo'] = pydantic.Field(
        'types.payments.ValidatedRequestedInfo',
        alias='_'
    )

    id: typing.Optional[str] = None
    shipping_options: typing.Optional[list["base.ShippingOption"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InlineQueryPeerType - Layer 181
InlineQueryPeerType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InlineQueryPeerTypeBotPM, pydantic.Tag('InlineQueryPeerTypeBotPM')],
        typing.Annotated[types.InlineQueryPeerTypeBroadcast, pydantic.Tag('InlineQueryPeerTypeBroadcast')],
        typing.Annotated[types.InlineQueryPeerTypeChat, pydantic.Tag('InlineQueryPeerTypeChat')],
        typing.Annotated[types.InlineQueryPeerTypeMegagroup, pydantic.Tag('InlineQueryPeerTypeMegagroup')],
        typing.Annotated[types.InlineQueryPeerTypePM, pydantic.Tag('InlineQueryPeerTypePM')],
        typing.Annotated[types.InlineQueryPeerTypeSameBotPM, pydantic.Tag('InlineQueryPeerTypeSameBotPM')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageReactions(BaseModel):
    """
    types.MessageReactions
    ID: 0x4f2b9479
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageReactions', 'MessageReactions'] = pydantic.Field(
        'types.MessageReactions',
        alias='_'
    )

    results: list["base.ReactionCount"]
    min: typing.Optional[bool] = None
    can_see_list: typing.Optional[bool] = None
    reactions_as_tags: typing.Optional[bool] = None
    recent_reactions: typing.Optional[list["base.MessagePeerReaction"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatInvite(BaseModel):
    """
    types.ChatInvite
    ID: 0xcde0ec40
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatInvite', 'ChatInvite'] = pydantic.Field(
        'types.ChatInvite',
        alias='_'
    )

    title: str
    photo: "base.Photo"
    participants_count: int
    color: int
    channel: typing.Optional[bool] = None
    broadcast: typing.Optional[bool] = None
    public: typing.Optional[bool] = None
    megagroup: typing.Optional[bool] = None
    request_needed: typing.Optional[bool] = None
    verified: typing.Optional[bool] = None
    scam: typing.Optional[bool] = None
    fake: typing.Optional[bool] = None
    about: typing.Optional[str] = None
    participants: typing.Optional[list["base.User"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPageAttributeTheme(BaseModel):
    """
    types.WebPageAttributeTheme
    ID: 0x54b56617
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPageAttributeTheme', 'WebPageAttributeTheme'] = pydantic.Field(
        'types.WebPageAttributeTheme',
        alias='_'
    )

    documents: typing.Optional[list["base.Document"]] = None
    settings: typing.Optional["base.ThemeSettings"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendReaction(BaseModel):
    """
    functions.messages.SendReaction
    ID: 0xd30d78d4
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SendReaction', 'SendReaction'] = pydantic.Field(
        'functions.messages.SendReaction',
        alias='_'
    )

    peer: "base.InputPeer"
    msg_id: int
    big: typing.Optional[bool] = None
    add_to_recent: typing.Optional[bool] = None
    reaction: typing.Optional[list["base.Reaction"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# DialogFilter - Layer 181
DialogFilter = typing.Annotated[
    typing.Union[
        typing.Annotated[types.DialogFilter, pydantic.Tag('DialogFilter')],
        typing.Annotated[types.DialogFilterChatlist, pydantic.Tag('DialogFilterChatlist')],
        typing.Annotated[types.DialogFilterDefault, pydantic.Tag('DialogFilterDefault')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.UserInfo - Layer 181
UserInfo = typing.Annotated[
    typing.Union[
        typing.Annotated[types.help.UserInfo, pydantic.Tag('help.UserInfo')],
        typing.Annotated[types.help.UserInfoEmpty, pydantic.Tag('help.UserInfoEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PremiumSubscriptionOption(BaseModel):
    """
    types.PremiumSubscriptionOption
    ID: 0x5f2d1df2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PremiumSubscriptionOption', 'PremiumSubscriptionOption'] = pydantic.Field(
        'types.PremiumSubscriptionOption',
        alias='_'
    )

    months: int
    currency: str
    amount: int
    bot_url: str
    current: typing.Optional[bool] = None
    can_purchase_upgrade: typing.Optional[bool] = None
    transaction: typing.Optional[str] = None
    store_product: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.StickerSet - Layer 181
StickerSet = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.StickerSet, pydantic.Tag('messages.StickerSet')],
        typing.Annotated[types.messages.StickerSetNotModified, pydantic.Tag('messages.StickerSetNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from .broadcast_stats import BroadcastStats
from .megagroup_stats import MegagroupStats
from .message_stats import MessageStats
from .story_stats import StoryStats
from .public_forwards import PublicForwards
from .broadcast_revenue_stats import BroadcastRevenueStats
from .broadcast_revenue_withdrawal_url import BroadcastRevenueWithdrawalUrl
from .broadcast_revenue_transactions import BroadcastRevenueTransactions



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineMessageGame(BaseModel):
    """
    types.InputBotInlineMessageGame
    ID: 0x4b425864
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineMessageGame', 'InputBotInlineMessageGame'] = pydantic.Field(
        'types.InputBotInlineMessageGame',
        alias='_'
    )

    reply_markup: typing.Optional["base.ReplyMarkup"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelAdminLogEventAction - Layer 181
ChannelAdminLogEventAction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChannelAdminLogEventActionChangeAbout, pydantic.Tag('ChannelAdminLogEventActionChangeAbout')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeAvailableReactions, pydantic.Tag('ChannelAdminLogEventActionChangeAvailableReactions')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeEmojiStatus, pydantic.Tag('ChannelAdminLogEventActionChangeEmojiStatus')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeEmojiStickerSet, pydantic.Tag('ChannelAdminLogEventActionChangeEmojiStickerSet')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeHistoryTTL, pydantic.Tag('ChannelAdminLogEventActionChangeHistoryTTL')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeLinkedChat, pydantic.Tag('ChannelAdminLogEventActionChangeLinkedChat')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeLocation, pydantic.Tag('ChannelAdminLogEventActionChangeLocation')],
        typing.Annotated[types.ChannelAdminLogEventActionChangePeerColor, pydantic.Tag('ChannelAdminLogEventActionChangePeerColor')],
        typing.Annotated[types.ChannelAdminLogEventActionChangePhoto, pydantic.Tag('ChannelAdminLogEventActionChangePhoto')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeProfilePeerColor, pydantic.Tag('ChannelAdminLogEventActionChangeProfilePeerColor')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeStickerSet, pydantic.Tag('ChannelAdminLogEventActionChangeStickerSet')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeTitle, pydantic.Tag('ChannelAdminLogEventActionChangeTitle')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeUsername, pydantic.Tag('ChannelAdminLogEventActionChangeUsername')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeUsernames, pydantic.Tag('ChannelAdminLogEventActionChangeUsernames')],
        typing.Annotated[types.ChannelAdminLogEventActionChangeWallpaper, pydantic.Tag('ChannelAdminLogEventActionChangeWallpaper')],
        typing.Annotated[types.ChannelAdminLogEventActionCreateTopic, pydantic.Tag('ChannelAdminLogEventActionCreateTopic')],
        typing.Annotated[types.ChannelAdminLogEventActionDefaultBannedRights, pydantic.Tag('ChannelAdminLogEventActionDefaultBannedRights')],
        typing.Annotated[types.ChannelAdminLogEventActionDeleteMessage, pydantic.Tag('ChannelAdminLogEventActionDeleteMessage')],
        typing.Annotated[types.ChannelAdminLogEventActionDeleteTopic, pydantic.Tag('ChannelAdminLogEventActionDeleteTopic')],
        typing.Annotated[types.ChannelAdminLogEventActionDiscardGroupCall, pydantic.Tag('ChannelAdminLogEventActionDiscardGroupCall')],
        typing.Annotated[types.ChannelAdminLogEventActionEditMessage, pydantic.Tag('ChannelAdminLogEventActionEditMessage')],
        typing.Annotated[types.ChannelAdminLogEventActionEditTopic, pydantic.Tag('ChannelAdminLogEventActionEditTopic')],
        typing.Annotated[types.ChannelAdminLogEventActionExportedInviteDelete, pydantic.Tag('ChannelAdminLogEventActionExportedInviteDelete')],
        typing.Annotated[types.ChannelAdminLogEventActionExportedInviteEdit, pydantic.Tag('ChannelAdminLogEventActionExportedInviteEdit')],
        typing.Annotated[types.ChannelAdminLogEventActionExportedInviteRevoke, pydantic.Tag('ChannelAdminLogEventActionExportedInviteRevoke')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantInvite, pydantic.Tag('ChannelAdminLogEventActionParticipantInvite')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantJoin, pydantic.Tag('ChannelAdminLogEventActionParticipantJoin')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantJoinByInvite, pydantic.Tag('ChannelAdminLogEventActionParticipantJoinByInvite')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantJoinByRequest, pydantic.Tag('ChannelAdminLogEventActionParticipantJoinByRequest')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantLeave, pydantic.Tag('ChannelAdminLogEventActionParticipantLeave')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantMute, pydantic.Tag('ChannelAdminLogEventActionParticipantMute')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantToggleAdmin, pydantic.Tag('ChannelAdminLogEventActionParticipantToggleAdmin')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantToggleBan, pydantic.Tag('ChannelAdminLogEventActionParticipantToggleBan')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantUnmute, pydantic.Tag('ChannelAdminLogEventActionParticipantUnmute')],
        typing.Annotated[types.ChannelAdminLogEventActionParticipantVolume, pydantic.Tag('ChannelAdminLogEventActionParticipantVolume')],
        typing.Annotated[types.ChannelAdminLogEventActionPinTopic, pydantic.Tag('ChannelAdminLogEventActionPinTopic')],
        typing.Annotated[types.ChannelAdminLogEventActionSendMessage, pydantic.Tag('ChannelAdminLogEventActionSendMessage')],
        typing.Annotated[types.ChannelAdminLogEventActionStartGroupCall, pydantic.Tag('ChannelAdminLogEventActionStartGroupCall')],
        typing.Annotated[types.ChannelAdminLogEventActionStopPoll, pydantic.Tag('ChannelAdminLogEventActionStopPoll')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleAntiSpam, pydantic.Tag('ChannelAdminLogEventActionToggleAntiSpam')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleForum, pydantic.Tag('ChannelAdminLogEventActionToggleForum')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleGroupCallSetting, pydantic.Tag('ChannelAdminLogEventActionToggleGroupCallSetting')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleInvites, pydantic.Tag('ChannelAdminLogEventActionToggleInvites')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleNoForwards, pydantic.Tag('ChannelAdminLogEventActionToggleNoForwards')],
        typing.Annotated[types.ChannelAdminLogEventActionTogglePreHistoryHidden, pydantic.Tag('ChannelAdminLogEventActionTogglePreHistoryHidden')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleSignatures, pydantic.Tag('ChannelAdminLogEventActionToggleSignatures')],
        typing.Annotated[types.ChannelAdminLogEventActionToggleSlowMode, pydantic.Tag('ChannelAdminLogEventActionToggleSlowMode')],
        typing.Annotated[types.ChannelAdminLogEventActionUpdatePinned, pydantic.Tag('ChannelAdminLogEventActionUpdatePinned')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputPeerPhotoFileLocation(BaseModel):
    """
    types.InputPeerPhotoFileLocation
    ID: 0x37257e99
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputPeerPhotoFileLocation', 'InputPeerPhotoFileLocation'] = pydantic.Field(
        'types.InputPeerPhotoFileLocation',
        alias='_'
    )

    peer: "base.InputPeer"
    photo_id: int
    big: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateReadChannelDiscussionInbox(BaseModel):
    """
    types.UpdateReadChannelDiscussionInbox
    ID: 0xd6b19546
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateReadChannelDiscussionInbox', 'UpdateReadChannelDiscussionInbox'] = pydantic.Field(
        'types.UpdateReadChannelDiscussionInbox',
        alias='_'
    )

    channel_id: int
    top_msg_id: int
    read_max_id: int
    broadcast_id: typing.Optional[int] = None
    broadcast_post: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaWebPage(BaseModel):
    """
    types.InputMediaWebPage
    ID: 0xc21b8849
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaWebPage', 'InputMediaWebPage'] = pydantic.Field(
        'types.InputMediaWebPage',
        alias='_'
    )

    url: str
    force_large_media: typing.Optional[bool] = None
    force_small_media: typing.Optional[bool] = None
    optional: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateConnectedBot(BaseModel):
    """
    functions.account.UpdateConnectedBot
    ID: 0x43d8521d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateConnectedBot', 'UpdateConnectedBot'] = pydantic.Field(
        'functions.account.UpdateConnectedBot',
        alias='_'
    )

    bot: "base.InputUser"
    recipients: "base.InputBusinessBotRecipients"
    can_reply: typing.Optional[bool] = None
    deleted: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GlobalPrivacySettings(BaseModel):
    """
    types.GlobalPrivacySettings
    ID: 0x734c4ccb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GlobalPrivacySettings', 'GlobalPrivacySettings'] = pydantic.Field(
        'types.GlobalPrivacySettings',
        alias='_'
    )

    archive_and_mute_new_noncontact_peers: typing.Optional[bool] = None
    keep_archived_unmuted: typing.Optional[bool] = None
    keep_archived_folders: typing.Optional[bool] = None
    hide_read_marks: typing.Optional[bool] = None
    new_noncontact_peers_require_premium: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# updates.ChannelDifference - Layer 181
ChannelDifference = typing.Annotated[
    typing.Union[
        typing.Annotated[types.updates.ChannelDifference, pydantic.Tag('updates.ChannelDifference')],
        typing.Annotated[types.updates.ChannelDifferenceEmpty, pydantic.Tag('updates.ChannelDifferenceEmpty')],
        typing.Annotated[types.updates.ChannelDifferenceTooLong, pydantic.Tag('updates.ChannelDifferenceTooLong')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetUserPhotos(BaseModel):
    """
    functions.photos.GetUserPhotos
    ID: 0x91cd32a8
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.photos.GetUserPhotos', 'GetUserPhotos'] = pydantic.Field(
        'functions.photos.GetUserPhotos',
        alias='_'
    )

    user_id: "base.InputUser"
    offset: int
    max_id: int
    limit: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatParticipantsForbidden(BaseModel):
    """
    types.ChatParticipantsForbidden
    ID: 0x8763d3e1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatParticipantsForbidden', 'ChatParticipantsForbidden'] = pydantic.Field(
        'types.ChatParticipantsForbidden',
        alias='_'
    )

    chat_id: int
    self_participant: typing.Optional["base.ChatParticipant"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Timezone(BaseModel):
    """
    types.Timezone
    ID: 0xff9289f5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Timezone', 'Timezone'] = pydantic.Field(
        'types.Timezone',
        alias='_'
    )

    id: str
    name: str
    utc_offset: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentCodeTypeSmsPhrase(BaseModel):
    """
    types.auth.SentCodeTypeSmsPhrase
    ID: 0xb37794af
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.SentCodeTypeSmsPhrase', 'SentCodeTypeSmsPhrase'] = pydantic.Field(
        'types.auth.SentCodeTypeSmsPhrase',
        alias='_'
    )

    beginning: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SecureSecretSettings(BaseModel):
    """
    types.SecureSecretSettings
    ID: 0x1527bcac
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SecureSecretSettings', 'SecureSecretSettings'] = pydantic.Field(
        'types.SecureSecretSettings',
        alias='_'
    )

    secure_algo: "base.SecurePasswordKdfAlgo"
    secure_secret: Bytes
    secure_secret_id: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.FoundStickerSets - Layer 181
FoundStickerSets = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.FoundStickerSets, pydantic.Tag('messages.FoundStickerSets')],
        typing.Annotated[types.messages.FoundStickerSetsNotModified, pydantic.Tag('messages.FoundStickerSetsNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputMessage - Layer 181
InputMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputMessageCallbackQuery, pydantic.Tag('InputMessageCallbackQuery')],
        typing.Annotated[types.InputMessageID, pydantic.Tag('InputMessageID')],
        typing.Annotated[types.InputMessagePinned, pydantic.Tag('InputMessagePinned')],
        typing.Annotated[types.InputMessageReplyTo, pydantic.Tag('InputMessageReplyTo')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.StickerSetInstallResult - Layer 181
StickerSetInstallResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.StickerSetInstallResultArchive, pydantic.Tag('messages.StickerSetInstallResultArchive')],
        typing.Annotated[types.messages.StickerSetInstallResultSuccess, pydantic.Tag('messages.StickerSetInstallResultSuccess')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionGiftPremium(BaseModel):
    """
    types.MessageActionGiftPremium
    ID: 0xc83d6aec
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionGiftPremium', 'MessageActionGiftPremium'] = pydantic.Field(
        'types.MessageActionGiftPremium',
        alias='_'
    )

    currency: str
    amount: int
    months: int
    crypto_currency: typing.Optional[str] = None
    crypto_amount: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputStorePaymentPremiumGiveaway(BaseModel):
    """
    types.InputStorePaymentPremiumGiveaway
    ID: 0x160544ca
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputStorePaymentPremiumGiveaway', 'InputStorePaymentPremiumGiveaway'] = pydantic.Field(
        'types.InputStorePaymentPremiumGiveaway',
        alias='_'
    )

    boost_peer: "base.InputPeer"
    random_id: int
    until_date: Datetime
    currency: str
    amount: int
    only_new_subscribers: typing.Optional[bool] = None
    winners_are_visible: typing.Optional[bool] = None
    additional_peers: typing.Optional[list["base.InputPeer"]] = None
    countries_iso2: typing.Optional[list[str]] = None
    prize_description: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.DhConfig - Layer 181
DhConfig = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.DhConfig, pydantic.Tag('messages.DhConfig')],
        typing.Annotated[types.messages.DhConfigNotModified, pydantic.Tag('messages.DhConfigNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebFile(BaseModel):
    """
    types.upload.WebFile
    ID: 0x21e753bc
    Layer: 181
    """
    QUALNAME: typing.Literal['types.upload.WebFile', 'WebFile'] = pydantic.Field(
        'types.upload.WebFile',
        alias='_'
    )

    size: int
    mime_type: str
    file_type: "base.storage.FileType"
    mtime: int
    bytes: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class File(BaseModel):
    """
    types.upload.File
    ID: 0x96a18d5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.upload.File', 'File'] = pydantic.Field(
        'types.upload.File',
        alias='_'
    )

    type: "base.storage.FileType"
    mtime: int
    bytes: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneCall(BaseModel):
    """
    types.PhoneCall
    ID: 0x30535af5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneCall', 'PhoneCall'] = pydantic.Field(
        'types.PhoneCall',
        alias='_'
    )

    id: int
    access_hash: int
    date: Datetime
    admin_id: int
    participant_id: int
    g_a_or_b: Bytes
    key_fingerprint: int
    protocol: "base.PhoneCallProtocol"
    connections: list["base.PhoneConnection"]
    start_date: Datetime
    p2p_allowed: typing.Optional[bool] = None
    video: typing.Optional[bool] = None
    custom_parameters: typing.Optional["base.DataJSON"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DropTempAuthKeys(BaseModel):
    """
    functions.auth.DropTempAuthKeys
    ID: 0x8e48a188
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.DropTempAuthKeys', 'DropTempAuthKeys'] = pydantic.Field(
        'functions.auth.DropTempAuthKeys',
        alias='_'
    )

    except_auth_keys: list[int]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendAsPeers(BaseModel):
    """
    types.channels.SendAsPeers
    ID: 0xf496b0c6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.channels.SendAsPeers', 'SendAsPeers'] = pydantic.Field(
        'types.channels.SendAsPeers',
        alias='_'
    )

    peers: list["base.SendAsPeer"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PaymentFormStars(BaseModel):
    """
    types.payments.PaymentFormStars
    ID: 0x7bf6b15c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.PaymentFormStars', 'PaymentFormStars'] = pydantic.Field(
        'types.payments.PaymentFormStars',
        alias='_'
    )

    form_id: int
    bot_id: int
    title: str
    description: str
    invoice: "base.Invoice"
    users: list["base.User"]
    photo: typing.Optional["base.WebDocument"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecureFile - Layer 181
SecureFile = typing.Annotated[
    typing.Union[
        typing.Annotated[types.SecureFile, pydantic.Tag('SecureFile')],
        typing.Annotated[types.SecureFileEmpty, pydantic.Tag('SecureFileEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CreateChannel(BaseModel):
    """
    functions.channels.CreateChannel
    ID: 0x91006707
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.CreateChannel', 'CreateChannel'] = pydantic.Field(
        'functions.channels.CreateChannel',
        alias='_'
    )

    title: str
    about: str
    broadcast: typing.Optional[bool] = None
    megagroup: typing.Optional[bool] = None
    for_import: typing.Optional[bool] = None
    forum: typing.Optional[bool] = None
    geo_point: typing.Optional["base.InputGeoPoint"] = None
    address: typing.Optional[str] = None
    ttl_period: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ForumTopic(BaseModel):
    """
    types.ForumTopic
    ID: 0x71701da9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ForumTopic', 'ForumTopic'] = pydantic.Field(
        'types.ForumTopic',
        alias='_'
    )

    id: int
    date: Datetime
    title: str
    icon_color: int
    top_message: int
    read_inbox_max_id: int
    read_outbox_max_id: int
    unread_count: int
    unread_mentions_count: int
    unread_reactions_count: int
    from_id: "base.Peer"
    notify_settings: "base.PeerNotifySettings"
    my: typing.Optional[bool] = None
    closed: typing.Optional[bool] = None
    pinned: typing.Optional[bool] = None
    short: typing.Optional[bool] = None
    hidden: typing.Optional[bool] = None
    icon_emoji_id: typing.Optional[int] = None
    draft: typing.Optional["base.DraftMessage"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RecentMeUrl - Layer 181
RecentMeUrl = typing.Annotated[
    typing.Union[
        typing.Annotated[types.RecentMeUrlChat, pydantic.Tag('RecentMeUrlChat')],
        typing.Annotated[types.RecentMeUrlChatInvite, pydantic.Tag('RecentMeUrlChatInvite')],
        typing.Annotated[types.RecentMeUrlStickerSet, pydantic.Tag('RecentMeUrlStickerSet')],
        typing.Annotated[types.RecentMeUrlUnknown, pydantic.Tag('RecentMeUrlUnknown')],
        typing.Annotated[types.RecentMeUrlUser, pydantic.Tag('RecentMeUrlUser')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StarsTransaction(BaseModel):
    """
    types.StarsTransaction
    ID: 0xcc7079b2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StarsTransaction', 'StarsTransaction'] = pydantic.Field(
        'types.StarsTransaction',
        alias='_'
    )

    id: str
    stars: int
    date: Datetime
    peer: "base.StarsTransactionPeer"
    refund: typing.Optional[bool] = None
    title: typing.Optional[str] = None
    description: typing.Optional[str] = None
    photo: typing.Optional["base.WebDocument"] = None



from .phone_call import PhoneCall
from .group_call import GroupCall
from .group_participants import GroupParticipants
from .join_as_peers import JoinAsPeers
from .exported_group_call_invite import ExportedGroupCallInvite
from .group_call_stream_channels import GroupCallStreamChannels
from .group_call_stream_rtmp_url import GroupCallStreamRtmpUrl



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageReplies(BaseModel):
    """
    types.MessageReplies
    ID: 0x83d60fc2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageReplies', 'MessageReplies'] = pydantic.Field(
        'types.MessageReplies',
        alias='_'
    )

    replies: int
    replies_pts: int
    comments: typing.Optional[bool] = None
    recent_repliers: typing.Optional[list["base.Peer"]] = None
    channel_id: typing.Optional[int] = None
    max_id: typing.Optional[int] = None
    read_max_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# UserStatus - Layer 181
UserStatus = typing.Annotated[
    typing.Union[
        typing.Annotated[types.UserStatusEmpty, pydantic.Tag('UserStatusEmpty')],
        typing.Annotated[types.UserStatusLastMonth, pydantic.Tag('UserStatusLastMonth')],
        typing.Annotated[types.UserStatusLastWeek, pydantic.Tag('UserStatusLastWeek')],
        typing.Annotated[types.UserStatusOffline, pydantic.Tag('UserStatusOffline')],
        typing.Annotated[types.UserStatusOnline, pydantic.Tag('UserStatusOnline')],
        typing.Annotated[types.UserStatusRecently, pydantic.Tag('UserStatusRecently')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Authorization(BaseModel):
    """
    types.auth.Authorization
    ID: 0x2ea2c0d4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.Authorization', 'Authorization'] = pydantic.Field(
        'types.auth.Authorization',
        alias='_'
    )

    user: "base.User"
    setup_password_required: typing.Optional[bool] = None
    otherwise_relogin_days: typing.Optional[int] = None
    tmp_sessions: typing.Optional[int] = None
    future_auth_token: typing.Optional[Bytes] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.SavedDialogs - Layer 181
SavedDialogs = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.SavedDialogs, pydantic.Tag('messages.SavedDialogs')],
        typing.Annotated[types.messages.SavedDialogsNotModified, pydantic.Tag('messages.SavedDialogsNotModified')],
        typing.Annotated[types.messages.SavedDialogsSlice, pydantic.Tag('messages.SavedDialogsSlice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhotoSize - Layer 181
PhotoSize = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PhotoCachedSize, pydantic.Tag('PhotoCachedSize')],
        typing.Annotated[types.PhotoPathSize, pydantic.Tag('PhotoPathSize')],
        typing.Annotated[types.PhotoSize, pydantic.Tag('PhotoSize')],
        typing.Annotated[types.PhotoSizeEmpty, pydantic.Tag('PhotoSizeEmpty')],
        typing.Annotated[types.PhotoSizeProgressive, pydantic.Tag('PhotoSizeProgressive')],
        typing.Annotated[types.PhotoStrippedSize, pydantic.Tag('PhotoStrippedSize')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AvailableEffects(BaseModel):
    """
    types.messages.AvailableEffects
    ID: 0xbddb616e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.AvailableEffects', 'AvailableEffects'] = pydantic.Field(
        'types.messages.AvailableEffects',
        alias='_'
    )

    hash: int
    effects: list["base.AvailableEffect"]
    documents: list["base.Document"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotShippingQuery(BaseModel):
    """
    types.UpdateBotShippingQuery
    ID: 0xb5aefd7d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotShippingQuery', 'UpdateBotShippingQuery'] = pydantic.Field(
        'types.UpdateBotShippingQuery',
        alias='_'
    )

    query_id: int
    user_id: int
    payload: Bytes
    shipping_address: "base.PostAddress"
